#include "config.h"
#include "hvif-light.h"

#include <stdio.h>
#include <stdlib.h>

int
main(int argc, char* argv[argc + 1])
{
	puts(PACKAGE_STRING);

	if (argc < 2) {
		if (argc > 0) printf("Usage: %s FILE\n", argv[0]);
		return EXIT_FAILURE;
	}

	FILE* imagefile = fopen(argv[1], "rb");
	if (!imagefile) {
		fputs("fopen failed.\n", stderr);
		return EXIT_FAILURE;
	}

	hvif_result result = hvif_from_file(imagefile);
	fclose(imagefile);

	if (result.status != SUCCESS) {
		fputs("Reading image failed.\n", stderr);
		switch (result.status) {
			case ERROR_NOMEM: fputs("Out of memory.\n", stderr); break;
			case ERROR_EOF: fputs("File ended prematurely.\n", stderr); break;
			case ERROR_STYLE: fputs("Incorrect style definition.\n", stderr); break;
			case ERROR_PATH: fputs("Incorrect path definition.\n", stderr); break;
			case ERROR_SHAPE: fputs("Incorrect shape definition.\n", stderr); break;
			default: break;
		}
		return EXIT_FAILURE;
	}
	puts("Reading image succeeded.");
	hvif_free(result.image);

	return EXIT_SUCCESS;
}
